aboutsummaryrefslogtreecommitdiff
path: root/src/lib/protocols/zeromq.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/protocols/zeromq.c')
-rw-r--r--src/lib/protocols/zeromq.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/protocols/zeromq.c b/src/lib/protocols/zeromq.c
index 8667d1994..6f86b856c 100644
--- a/src/lib/protocols/zeromq.c
+++ b/src/lib/protocols/zeromq.c
@@ -37,8 +37,8 @@ static void ndpi_check_zmq(struct ndpi_detection_module_struct *ndpi_struct, str
u_char p1[] = { 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x7f };
u_char p2[] = { 0x28, 0x66, 0x6c, 0x6f, 0x77, 0x00 };
- /* Break after 17 packets. */
- if(flow->packet_counter > 17) {
+ /* Break after 10 packets. */
+ if(flow->packet_counter > 10) {
NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
return;
}